==> watchmen_storage_postgresql-16.4.4-py3-none-any.whl: watchmen_storage_postgresql/storage_postgresql_configuration.py <==
from __future__ import annotations

from watchmen_model.system import DataSource, DataSourceType
from .data_source_postgresql import PostgreSQLDataSourceHelper, PostgreSQLDataSourceParams
from .storage_postgresql import StoragePostgreSQL, TopicDataStoragePostgreSQL


# noinspection PyRedeclaration
class Configuration:
	dataSource: DataSource = DataSource(dataSourceType=DataSourceType.POSTGRESQL)
	params: PostgreSQLDataSourceParams = PostgreSQLDataSourceParams()

	def host(self, host: str, port: int = 3306) -> Configuration:
		self.dataSource.host = host
		self.dataSource.port = str(port)
		return self

	def account(self, username: str, password: str) -> Configuration:
		self.dataSource.username = username
		self.dataSource.password = password
		return self

	def url(self, url: str) -> Configuration:
		"""
		url should include account information, like:
		1. postgresql://username:password@host:port/dbname
		2. postgresql+psycopg2://username:password@host:port/dbname
		"""
		self.dataSource.url = url
		return self

	def schema(self, schema: str) -> Configuration:
		self.dataSource.name = schema
		return self

	def echo(self, enabled: bool = False) -> Configuration:
		self.params.echo = enabled
		return self

	def build(self) -> StoragePostgreSQL:
		return StoragePostgreSQLConfiguration(self.dataSource, self.params).create_storage()

	def build_topic_data(self) -> TopicDataStoragePostgreSQL:
		return StoragePostgreSQLConfiguration(self.dataSource, self.params).create_topic_data_storage()


class StoragePostgreSQLConfiguration:
	"""
	configuration of PostgreSQL storage
	"""

	def __init__(self, data_source: DataSource, params: PostgreSQLDataSourceParams):
		super().__init__()
		self.helper = PostgreSQLDataSourceHelper(data_source, params)

	def create_storage(self) -> StoragePostgreSQL:
		return self.helper.acquire_storage()

	def create_topic_data_storage(self) -> TopicDataStoragePostgreSQL:
		return self.helper.acquire_topic_data_storage()

	@staticmethod
	def config() -> Configuration:
		return Configuration()

==> watchmen_storage_postgresql-16.5.29-py3-none-any.whl: watchmen_storage_postgresql/storage_postgresql_configuration.py <==
from __future__ import annotations

from watchmen_model.system import DataSource, DataSourceType

from .data_source_postgresql import PostgreSQLDataSourceHelper, PostgreSQLDataSourceParams
from .storage_postgresql import StoragePostgreSQL, TopicDataStoragePostgreSQL


# noinspection PyRedeclaration
class Configuration:
	dataSource: DataSource = DataSource(dataSourceType=DataSourceType.POSTGRESQL)
	params: PostgreSQLDataSourceParams = PostgreSQLDataSourceParams()
	storageHolder: StoragePostgreSQLConfiguration = None

	def host(self, host: str, port: int = 3306) -> Configuration:
		self.dataSource.host = host
		self.dataSource.port = str(port)
		return self

	def account(self, username: str, password: str) -> Configuration:
		self.dataSource.username = username
		self.dataSource.password = password
		return self

	def url(self, url: str) -> Configuration:
		"""
		url should include account information, like:
		1. postgresql://username:password@host:port/dbname
		2. postgresql+psycopg2://username:password@host:port/dbname
		"""
		self.dataSource.url = url
		return self

	def schema(self, schema: str) -> Configuration:
		self.dataSource.name = schema
		return self

	def echo(self, enabled: bool = False) -> Configuration:
		self.params.echo = enabled
		return self

	def get_or_create_storage_holder(self) -> StoragePostgreSQLConfiguration:
		if self.storageHolder is None:
			self.storageHolder = StoragePostgreSQLConfiguration(self.dataSource, self.params)
		return self.storageHolder

	def build(self) -> StoragePostgreSQL:
		return self.get_or_create_storage_holder().create_storage()

	def build_topic_data(self) -> TopicDataStoragePostgreSQL:
		return self.get_or_create_storage_holder().create_topic_data_storage()


class StoragePostgreSQLConfiguration:
	"""
	configuration of PostgreSQL storage
	"""

	def __init__(self, data_source: DataSource, params: PostgreSQLDataSourceParams):
		super().__init__()
		self.helper = PostgreSQLDataSourceHelper(data_source, params)

	def create_storage(self) -> StoragePostgreSQL:
		return self.helper.acquire_storage()

	def create_topic_data_storage(self) -> TopicDataStoragePostgreSQL:
		return self.helper.acquire_topic_data_storage()

	@staticmethod
	def config() -> Configuration:
		return Configuration()
